@@ -1,6 +1,13 @@
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2020 Dhruv Manilawala <dhruvmanila@gmail.com>                      #
+# Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2021 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2021 majorvin <majorvin.tan@outlook.com>                           #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -51,7 +58,10 @@ if TYPE_CHECKING:
 class CheckRun(CompletableGithubObject):
     """
     This class represents check runs.
-    The reference can be found here https://docs.github.com/en/rest/reference/checks#check-runs
+
+    The reference can be found here
+    https://docs.github.com/en/rest/reference/checks#check-runs
+
     """
 
     def _initAttributes(self) -> None:
