@@ -10,6 +10,15 @@
 # Copyright 2017 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2019 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2021 Mark Walker <mark.walker@realbuzz.com>                        #
+# Copyright 2021 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -28,6 +37,7 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+
 from __future__ import annotations
 
 from datetime import datetime
@@ -40,7 +50,11 @@ from github.GithubObject import Attribute, CompletableGithubObject, NotSet, Opt,
 
 class Hook(CompletableGithubObject):
     """
-    This class represents Hooks. The reference can be found here https://docs.github.com/en/rest/reference/repos#webhooks
+    This class represents Hooks.
+
+    The reference can be found here
+    https://docs.github.com/en/rest/reference/repos#webhooks
+
     """
 
     def _initAttributes(self) -> None:
