@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
@@ -9,6 +7,12 @@
 # Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2019 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -28,32 +32,30 @@
 #                                                                              #
 ################################################################################
 
-import github.GithubObject
+
+from __future__ import annotations
+
+from typing import Any
+
+from github.GithubObject import NotSet, Opt, is_defined, is_optional
 
 
-class InputFileContent(object):
+class InputFileContent:
     """
-    This class represents InputFileContents
+    This class represents InputFileContents.
     """
 
-    def __init__(self, content, new_name=github.GithubObject.NotSet):
-        """
-        :param content: string
-        :param new_name: string
-        """
-
+    def __init__(self, content: str, new_name: Opt[str] = NotSet):
         assert isinstance(content, str), content
-        assert new_name is github.GithubObject.NotSet or isinstance(
-            new_name, str
-        ), new_name
-        self.__newName = new_name
-        self.__content = content
+        assert is_optional(new_name, str), new_name
+        self.__newName: Opt[str] = new_name
+        self.__content: str = content
 
     @property
-    def _identity(self):
-        identity = {
+    def _identity(self) -> dict[str, str]:
+        identity: dict[str, Any] = {
             "content": self.__content,
         }
-        if self.__newName is not github.GithubObject.NotSet:
+        if is_defined(self.__newName):
             identity["filename"] = self.__newName
         return identity
