@@ -1,11 +1,22 @@
 ############################ Copyrights and license ############################
 #                                                                              #
+# Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2012 Zearin <zearin@gonk.net>                                      #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2016 Jannis Gebauer <ja.geb@me.com>                                #
 # Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2019 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2021 Mark Walker <mark.walker@realbuzz.com>                        #
+# Copyright 2021 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -25,58 +36,59 @@
 #                                                                              #
 ################################################################################
 
-import github.GithubObject
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any
+
 import github.Rate
+from github.GithubObject import Attribute, NonCompletableGithubObject, NotSet
+
+if TYPE_CHECKING:
+    from github.Rate import Rate
 
 
-class RateLimit(github.GithubObject.NonCompletableGithubObject):
+class RateLimit(NonCompletableGithubObject):
     """
-    This class represents RateLimits. The reference can be found here https://docs.github.com/en/rest/reference/rate-limit
+    This class represents RateLimits.
+
+    The reference can be found here
+    https://docs.github.com/en/rest/reference/rate-limit
+
     """
 
-    def __repr__(self):
+    def _initAttributes(self) -> None:
+        self._core: Attribute[Rate] = NotSet
+        self._search: Attribute[Rate] = NotSet
+        self._graphql: Attribute[Rate] = NotSet
+
+    def __repr__(self) -> str:
         return self.get__repr__({"core": self._core.value})
 
     @property
-    def core(self):
+    def core(self) -> Rate:
         """
-        Rate limit for the non-search-related API
-
-        :type: class:`github.Rate.Rate`
+        Rate limit for the non-search-related API.
         """
         return self._core.value
 
     @property
-    def search(self):
+    def search(self) -> Rate:
         """
         Rate limit for the Search API.
-
-        :type: class:`github.Rate.Rate`
         """
         return self._search.value
 
     @property
-    def graphql(self):
+    def graphql(self) -> Rate:
         """
         (Experimental) Rate limit for GraphQL API, use with caution.
-
-        :type: class:`github.Rate.Rate`
         """
         return self._graphql.value
 
-    def _initAttributes(self):
-        self._core = github.GithubObject.NotSet
-        self._search = github.GithubObject.NotSet
-        self._graphql = github.GithubObject.NotSet
-
-    def _useAttributes(self, attributes):
+    def _useAttributes(self, attributes: dict[str, Any]) -> None:
         if "core" in attributes:  # pragma no branch
             self._core = self._makeClassAttribute(github.Rate.Rate, attributes["core"])
         if "search" in attributes:  # pragma no branch
-            self._search = self._makeClassAttribute(
-                github.Rate.Rate, attributes["search"]
-            )
+            self._search = self._makeClassAttribute(github.Rate.Rate, attributes["search"])
         if "graphql" in attributes:  # pragma no branch
-            self._graphql = self._makeClassAttribute(
-                github.Rate.Rate, attributes["graphql"]
-            )
+            self._graphql = self._makeClassAttribute(github.Rate.Rate, attributes["graphql"])
