@@ -14,6 +14,15 @@
 # Copyright 2018 Laurent Raufaste <analogue@glop.org>                          #
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2019 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2021 Floyd Hightower <floyd.hightower27@gmail.com>                 #
+# Copyright 2021 Mark Walker <mark.walker@realbuzz.com>                        #
+# Copyright 2021 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -32,6 +41,7 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+
 from datetime import datetime
 from typing import Any, Dict
 
@@ -40,7 +50,11 @@ from github.GithubObject import Attribute, CompletableGithubObject, NotSet
 
 class RepositoryKey(CompletableGithubObject):
     """
-    This class represents RepositoryKeys. The reference can be found here https://docs.github.com/en/rest/reference/repos#deploy-keys
+    This class represents RepositoryKeys.
+
+    The reference can be found here
+    https://docs.github.com/en/rest/reference/repos#deploy-keys
+
     """
 
     def _initAttributes(self) -> None:
