@@ -1,6 +1,16 @@
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2018 Hayden Fuss <wifu1234@gmail.com>                              #
+# Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2019 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2019 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2021 Mark Walker <mark.walker@realbuzz.com>                        #
+# Copyright 2021 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -19,6 +29,7 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+
 from __future__ import annotations
 
 from typing import Any
@@ -29,7 +40,11 @@ from github.GithubObject import Attribute, CompletableGithubObject, NotSet
 
 class SourceImport(CompletableGithubObject):
     """
-    This class represents SourceImports. The reference can be found here https://docs.github.com/en/rest/reference/migrations#source-imports
+    This class represents SourceImports.
+
+    The reference can be found here
+    https://docs.github.com/en/rest/reference/migrations#source-imports
+
     """
 
     def _initAttributes(self) -> None:
